Module value

Module value 

Conversions between Rust types and FIX wire representations of field values.

Structs

FixDate
A FIX UTCDateOnly / LocalMktDate: YYYYMMDD.
UtcTimestamp
A FIX UTCTimestamp: YYYYMMDD-HH:MM:SS[.sss[sss[sss]]].

Enums

TimestampPrecision
Precision used when encoding UTCTimestamp values (tag 52 et al).

Traits

FixDecode
A value that can be parsed from a FIX field value.
FixEncode
A value that can be written as a FIX field value.